@@ -435,7 +435,7 @@ namespace Proc {
 	void tree_sort(vector<tree_proc>& proc_vec, const string& sorting,
 				   bool reverse, int& c_index, const int index_max, bool collapsed = false);
 
-	bool matches_filter(const proc_info& proc, const std::string& filter);
+	auto matches_filter(const proc_info& proc, const std::string& filter) -> bool;
 
 	//* Generate process tree list
 	void _tree_gen(proc_info& cur_proc, vector<proc_info>& in_procs, vector<tree_proc>& out_procs,
